@@ -187,7 +187,7 @@ import nflgame.player
 import nflgame.schedule
 import nflgame.seq
 
-VERSION = "1.1.10"
+VERSION = "1.1.11"
 
 NoPlayers = nflgame.seq.GenPlayerStats(None)
 """
@@ -214,25 +214,25 @@ teams = [
     ['DAL', 'Dallas', 'Cowboys', 'Dallas Cowboys'],
     ['DEN', 'Denver', 'Broncos', 'Denver Broncos'],
     ['DET', 'Detroit', 'Lions', 'Detroit Lions'],
-    ['GB', 'Green Bay', 'Packers', 'Green Bay Packers', 'G.B.'],
+    ['GB', 'Green Bay', 'Packers', 'Green Bay Packers', 'G.B.', 'GNB'],
     ['HOU', 'Houston', 'Texans', 'Houston Texans'],
     ['IND', 'Indianapolis', 'Colts', 'Indianapolis Colts'],
     ['JAC', 'Jacksonville', 'Jaguars', 'Jacksonville Jaguars', 'JAX'],
-    ['KC', 'Kansas City', 'Chiefs', 'Kansas City Chiefs', 'K.C.'],
+    ['KC', 'Kansas City', 'Chiefs', 'Kansas City Chiefs', 'K.C.', 'KAN'],
     ['MIA', 'Miami', 'Dolphins', 'Miami Dolphins'],
     ['MIN', 'Minnesota', 'Vikings', 'Minnesota Vikings'],
-    ['NE', 'New England', 'Patriots', 'New England Patriots', 'N.E.'],
-    ['NO', 'New Orleans', 'Saints', 'New Orleans Saints', 'N.O.'],
+    ['NE', 'New England', 'Patriots', 'New England Patriots', 'N.E.', 'NWE'],
+    ['NO', 'New Orleans', 'Saints', 'New Orleans Saints', 'N.O.', 'NOR'],
     ['NYG', 'Giants', 'New York Giants', 'N.Y.G.'],
     ['NYJ', 'Jets', 'New York Jets', 'N.Y.J.'],
     ['OAK', 'Oakland', 'Raiders', 'Oakland Raiders'],
     ['PHI', 'Philadelphia', 'Eagles', 'Philadelphia Eagles'],
     ['PIT', 'Pittsburgh', 'Steelers', 'Pittsburgh Steelers'],
-    ['SD', 'San Diego', 'Chargers', 'San Diego Chargers', 'S.D.'],
+    ['SD', 'San Diego', 'Chargers', 'San Diego Chargers', 'S.D.', 'SDG'],
     ['SEA', 'Seattle', 'Seahawks', 'Seattle Seahawks'],
-    ['SF', 'San Francisco', '49ers', 'San Francisco 49ers', 'S.F.'],
+    ['SF', 'San Francisco', '49ers', 'San Francisco 49ers', 'S.F.', 'SFO'],
     ['STL', 'St. Louis', 'Rams', 'St. Louis Rams', 'S.T.L.'],
-    ['TB', 'Tampa Bay', 'Buccaneers', 'Tampa Bay Buccaneers', 'T.B.'],
+    ['TB', 'Tampa Bay', 'Buccaneers', 'Tampa Bay Buccaneers', 'T.B.', 'TAM'],
     ['TEN', 'Tennessee', 'Titans', 'Tennessee Titans'],
     ['WAS', 'Washington', 'Redskins', 'Washington Redskins', 'WSH'],
 ]
